/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
import groovy.xml.MarkupBuilder

class BuilderPerfTest extends GroovyTestCase {
    void formatAsXml(Writer writer) {
        def builder = new MarkupBuilder(writer)

        builder.Bookings {
            Booking {
                Origin("Auckland")
                Destination("Wellington")
                PassengerName("Mr John Smith")
            }
            Payment {
                From("J Smith")
                Amount(42)
            }
        }
    }

    void testMe () {
        long start = System.currentTimeMillis()
        def writer
        5000.times({
            writer = new StringWriter()
            formatAsXml(writer)
        })
        println "Took ${System.currentTimeMillis() - start} millis"
    }
}
