/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package groovy.bugs

class Groovy4861Bug extends GroovyTestCase {
    void testCallSitesUsageInNestedInterface() {
        assert Foo4861.A.j == 3
        assert Foo4861.A.j2 == 7
        assert new Foo4861()
    }
}

@groovy.transform.PackageScope class Foo4861 {
    static interface A {
        static Integer j = 3
        static Integer j2 = j + 4
    }
    static interface B{}
    static class Inner<X> {}
    static Inner<A> method() { null }
}
