/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package groovy

class CompareToTest extends GroovyTestCase {

    void testCompareTo() {

        def a = 12
        def b = 20
        def c = 30
        
        def result = a <=> b
        assert result < 0

        result = a <=> 12
        assert result == 0

        result = c <=> b
        assert result > 0
        
        assert (a <=> b) < 0
        assert a <=> 12 == 0
        assert (c <=> b) > 0
    }

    void testNullCompares() {
    
        def a = 123
        def b = null
        
        def result = a <=> b
        assert result > 0
        
        result = b <=> a
        assert result < 0
        
        result = b <=> null
        assert result == 0
    }
}
