/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
package groovy.transform.stc

class Groovy7907Bug extends StaticTypeCheckingTestCase {
    void testPlaceholdersInPrecompiledBinariesShouldBeHonored() {
        assertScript '''
            import groovy.transform.stc.*

            def method() {
                Ext create1 = new Groovy7907HelperPrecompiledJava().create(Ext)
                Ext create2 = new Groovy7907HelperPrecompiledGroovy().create(Ext)
                Ext create3 = new Groovy7907Helper().create(Ext)
            }

            class Groovy7907Helper {
                public <T extends Object> T create(Class<T> type, Object... args) { null }
            }

            class Ext {}

            method()
        '''
    }
}
